"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Channel(google.protobuf.message.Message):
    """Channel is a logical grouping of channels, subchannels, and sockets."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REF_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    CHANNEL_REF_FIELD_NUMBER: builtins.int
    SUBCHANNEL_REF_FIELD_NUMBER: builtins.int
    SOCKET_REF_FIELD_NUMBER: builtins.int
    @property
    def ref(self) -> global___ChannelRef:
        """The identifier for this channel. This should be set."""
        pass
    @property
    def data(self) -> global___ChannelData:
        """Data specific to this channel.
        At most one of 'channel_ref+subchannel_ref' and 'socket' is set.
        """
        pass
    @property
    def channel_ref(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChannelRef]:
        """There are no ordering guarantees on the order of channel refs.
        There may not be cycles in the ref graph.
        A channel ref may be present in more than one channel or subchannel.
        """
        pass
    @property
    def subchannel_ref(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubchannelRef]:
        """At most one of 'channel_ref+subchannel_ref' and 'socket' is set.
        There are no ordering guarantees on the order of subchannel refs.
        There may not be cycles in the ref graph.
        A sub channel ref may be present in more than one channel or subchannel.
        """
        pass
    @property
    def socket_ref(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SocketRef]:
        """There are no ordering guarantees on the order of sockets."""
        pass
    def __init__(self,
        *,
        ref: typing.Optional[global___ChannelRef] = ...,
        data: typing.Optional[global___ChannelData] = ...,
        channel_ref: typing.Optional[typing.Iterable[global___ChannelRef]] = ...,
        subchannel_ref: typing.Optional[typing.Iterable[global___SubchannelRef]] = ...,
        socket_ref: typing.Optional[typing.Iterable[global___SocketRef]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data",b"data","ref",b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_ref",b"channel_ref","data",b"data","ref",b"ref","socket_ref",b"socket_ref","subchannel_ref",b"subchannel_ref"]) -> None: ...
global___Channel = Channel

class Subchannel(google.protobuf.message.Message):
    """Subchannel is a logical grouping of channels, subchannels, and sockets.
    A subchannel is load balanced over by it's ancestor
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REF_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    CHANNEL_REF_FIELD_NUMBER: builtins.int
    SUBCHANNEL_REF_FIELD_NUMBER: builtins.int
    SOCKET_REF_FIELD_NUMBER: builtins.int
    @property
    def ref(self) -> global___SubchannelRef:
        """The identifier for this channel."""
        pass
    @property
    def data(self) -> global___ChannelData:
        """Data specific to this channel.
        At most one of 'channel_ref+subchannel_ref' and 'socket' is set.
        """
        pass
    @property
    def channel_ref(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChannelRef]:
        """There are no ordering guarantees on the order of channel refs.
        There may not be cycles in the ref graph.
        A channel ref may be present in more than one channel or subchannel.
        """
        pass
    @property
    def subchannel_ref(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubchannelRef]:
        """At most one of 'channel_ref+subchannel_ref' and 'socket' is set.
        There are no ordering guarantees on the order of subchannel refs.
        There may not be cycles in the ref graph.
        A sub channel ref may be present in more than one channel or subchannel.
        """
        pass
    @property
    def socket_ref(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SocketRef]:
        """There are no ordering guarantees on the order of sockets."""
        pass
    def __init__(self,
        *,
        ref: typing.Optional[global___SubchannelRef] = ...,
        data: typing.Optional[global___ChannelData] = ...,
        channel_ref: typing.Optional[typing.Iterable[global___ChannelRef]] = ...,
        subchannel_ref: typing.Optional[typing.Iterable[global___SubchannelRef]] = ...,
        socket_ref: typing.Optional[typing.Iterable[global___SocketRef]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data",b"data","ref",b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_ref",b"channel_ref","data",b"data","ref",b"ref","socket_ref",b"socket_ref","subchannel_ref",b"subchannel_ref"]) -> None: ...
global___Subchannel = Subchannel

class ChannelConnectivityState(google.protobuf.message.Message):
    """These come from the specified states in this document:
    https://github.com/grpc/grpc/blob/master/doc/connectivity-semantics-and-api.md
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _State:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChannelConnectivityState._State.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ChannelConnectivityState._State.ValueType  # 0
        IDLE: ChannelConnectivityState._State.ValueType  # 1
        CONNECTING: ChannelConnectivityState._State.ValueType  # 2
        READY: ChannelConnectivityState._State.ValueType  # 3
        TRANSIENT_FAILURE: ChannelConnectivityState._State.ValueType  # 4
        SHUTDOWN: ChannelConnectivityState._State.ValueType  # 5
    class State(_State, metaclass=_StateEnumTypeWrapper):
        pass

    UNKNOWN: ChannelConnectivityState.State.ValueType  # 0
    IDLE: ChannelConnectivityState.State.ValueType  # 1
    CONNECTING: ChannelConnectivityState.State.ValueType  # 2
    READY: ChannelConnectivityState.State.ValueType  # 3
    TRANSIENT_FAILURE: ChannelConnectivityState.State.ValueType  # 4
    SHUTDOWN: ChannelConnectivityState.State.ValueType  # 5

    STATE_FIELD_NUMBER: builtins.int
    state: global___ChannelConnectivityState.State.ValueType
    def __init__(self,
        *,
        state: global___ChannelConnectivityState.State.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["state",b"state"]) -> None: ...
global___ChannelConnectivityState = ChannelConnectivityState

class ChannelData(google.protobuf.message.Message):
    """Channel data is data related to a specific Channel or Subchannel."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TRACE_FIELD_NUMBER: builtins.int
    CALLS_STARTED_FIELD_NUMBER: builtins.int
    CALLS_SUCCEEDED_FIELD_NUMBER: builtins.int
    CALLS_FAILED_FIELD_NUMBER: builtins.int
    LAST_CALL_STARTED_TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def state(self) -> global___ChannelConnectivityState:
        """The connectivity state of the channel or subchannel.  Implementations
        should always set this.
        """
        pass
    target: typing.Text
    """The target this channel originally tried to connect to.  May be absent"""

    @property
    def trace(self) -> global___ChannelTrace:
        """A trace of recent events on the channel.  May be absent."""
        pass
    calls_started: builtins.int
    """The number of calls started on the channel"""

    calls_succeeded: builtins.int
    """The number of calls that have completed with an OK status"""

    calls_failed: builtins.int
    """The number of calls that have completed with a non-OK status"""

    @property
    def last_call_started_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The last time a call was started on the channel."""
        pass
    def __init__(self,
        *,
        state: typing.Optional[global___ChannelConnectivityState] = ...,
        target: typing.Text = ...,
        trace: typing.Optional[global___ChannelTrace] = ...,
        calls_started: builtins.int = ...,
        calls_succeeded: builtins.int = ...,
        calls_failed: builtins.int = ...,
        last_call_started_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_call_started_timestamp",b"last_call_started_timestamp","state",b"state","trace",b"trace"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["calls_failed",b"calls_failed","calls_started",b"calls_started","calls_succeeded",b"calls_succeeded","last_call_started_timestamp",b"last_call_started_timestamp","state",b"state","target",b"target","trace",b"trace"]) -> None: ...
global___ChannelData = ChannelData

class ChannelTraceEvent(google.protobuf.message.Message):
    """A trace event is an interesting thing that happened to a channel or
    subchannel, such as creation, address resolution, subchannel creation, etc.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Severity:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _SeverityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChannelTraceEvent._Severity.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CT_UNKNOWN: ChannelTraceEvent._Severity.ValueType  # 0
        CT_INFO: ChannelTraceEvent._Severity.ValueType  # 1
        CT_WARNING: ChannelTraceEvent._Severity.ValueType  # 2
        CT_ERROR: ChannelTraceEvent._Severity.ValueType  # 3
    class Severity(_Severity, metaclass=_SeverityEnumTypeWrapper):
        """The supported severity levels of trace events."""
        pass

    CT_UNKNOWN: ChannelTraceEvent.Severity.ValueType  # 0
    CT_INFO: ChannelTraceEvent.Severity.ValueType  # 1
    CT_WARNING: ChannelTraceEvent.Severity.ValueType  # 2
    CT_ERROR: ChannelTraceEvent.Severity.ValueType  # 3

    DESCRIPTION_FIELD_NUMBER: builtins.int
    SEVERITY_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    CHANNEL_REF_FIELD_NUMBER: builtins.int
    SUBCHANNEL_REF_FIELD_NUMBER: builtins.int
    description: typing.Text
    """High level description of the event."""

    severity: global___ChannelTraceEvent.Severity.ValueType
    """the severity of the trace event"""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When this event occurred."""
        pass
    @property
    def channel_ref(self) -> global___ChannelRef: ...
    @property
    def subchannel_ref(self) -> global___SubchannelRef: ...
    def __init__(self,
        *,
        description: typing.Text = ...,
        severity: global___ChannelTraceEvent.Severity.ValueType = ...,
        timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        channel_ref: typing.Optional[global___ChannelRef] = ...,
        subchannel_ref: typing.Optional[global___SubchannelRef] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["channel_ref",b"channel_ref","child_ref",b"child_ref","subchannel_ref",b"subchannel_ref","timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_ref",b"channel_ref","child_ref",b"child_ref","description",b"description","severity",b"severity","subchannel_ref",b"subchannel_ref","timestamp",b"timestamp"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["child_ref",b"child_ref"]) -> typing.Optional[typing_extensions.Literal["channel_ref","subchannel_ref"]]: ...
global___ChannelTraceEvent = ChannelTraceEvent

class ChannelTrace(google.protobuf.message.Message):
    """ChannelTrace represents the recent events that have occurred on the channel."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NUM_EVENTS_LOGGED_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    num_events_logged: builtins.int
    """Number of events ever logged in this tracing object. This can differ from
    events.size() because events can be overwritten or garbage collected by
    implementations.
    """

    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time that this channel was created."""
        pass
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChannelTraceEvent]:
        """List of events that have occurred on this channel."""
        pass
    def __init__(self,
        *,
        num_events_logged: builtins.int = ...,
        creation_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        events: typing.Optional[typing.Iterable[global___ChannelTraceEvent]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp",b"creation_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp",b"creation_timestamp","events",b"events","num_events_logged",b"num_events_logged"]) -> None: ...
global___ChannelTrace = ChannelTrace

class ChannelRef(google.protobuf.message.Message):
    """ChannelRef is a reference to a Channel."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    channel_id: builtins.int
    """The globally unique id for this channel.  Must be a positive number."""

    name: typing.Text
    """An optional name associated with the channel."""

    def __init__(self,
        *,
        channel_id: builtins.int = ...,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_id",b"channel_id","name",b"name"]) -> None: ...
global___ChannelRef = ChannelRef

class SubchannelRef(google.protobuf.message.Message):
    """SubchannelRef is a reference to a Subchannel."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SUBCHANNEL_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    subchannel_id: builtins.int
    """The globally unique id for this subchannel.  Must be a positive number."""

    name: typing.Text
    """An optional name associated with the subchannel."""

    def __init__(self,
        *,
        subchannel_id: builtins.int = ...,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name","subchannel_id",b"subchannel_id"]) -> None: ...
global___SubchannelRef = SubchannelRef

class SocketRef(google.protobuf.message.Message):
    """SocketRef is a reference to a Socket."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SOCKET_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    socket_id: builtins.int
    """The globally unique id for this socket.  Must be a positive number."""

    name: typing.Text
    """An optional name associated with the socket."""

    def __init__(self,
        *,
        socket_id: builtins.int = ...,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name","socket_id",b"socket_id"]) -> None: ...
global___SocketRef = SocketRef

class ServerRef(google.protobuf.message.Message):
    """ServerRef is a reference to a Server."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SERVER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    server_id: builtins.int
    """A globally unique identifier for this server.  Must be a positive number."""

    name: typing.Text
    """An optional name associated with the server."""

    def __init__(self,
        *,
        server_id: builtins.int = ...,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name","server_id",b"server_id"]) -> None: ...
global___ServerRef = ServerRef

class Server(google.protobuf.message.Message):
    """Server represents a single server.  There may be multiple servers in a single
    program.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REF_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    LISTEN_SOCKET_FIELD_NUMBER: builtins.int
    @property
    def ref(self) -> global___ServerRef:
        """The identifier for a Server.  This should be set."""
        pass
    @property
    def data(self) -> global___ServerData:
        """The associated data of the Server."""
        pass
    @property
    def listen_socket(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SocketRef]:
        """The sockets that the server is listening on.  There are no ordering
        guarantees.  This may be absent.
        """
        pass
    def __init__(self,
        *,
        ref: typing.Optional[global___ServerRef] = ...,
        data: typing.Optional[global___ServerData] = ...,
        listen_socket: typing.Optional[typing.Iterable[global___SocketRef]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data",b"data","ref",b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data","listen_socket",b"listen_socket","ref",b"ref"]) -> None: ...
global___Server = Server

class ServerData(google.protobuf.message.Message):
    """ServerData is data for a specific Server."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRACE_FIELD_NUMBER: builtins.int
    CALLS_STARTED_FIELD_NUMBER: builtins.int
    CALLS_SUCCEEDED_FIELD_NUMBER: builtins.int
    CALLS_FAILED_FIELD_NUMBER: builtins.int
    LAST_CALL_STARTED_TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def trace(self) -> global___ChannelTrace:
        """A trace of recent events on the server.  May be absent."""
        pass
    calls_started: builtins.int
    """The number of incoming calls started on the server"""

    calls_succeeded: builtins.int
    """The number of incoming calls that have completed with an OK status"""

    calls_failed: builtins.int
    """The number of incoming calls that have a completed with a non-OK status"""

    @property
    def last_call_started_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The last time a call was started on the server."""
        pass
    def __init__(self,
        *,
        trace: typing.Optional[global___ChannelTrace] = ...,
        calls_started: builtins.int = ...,
        calls_succeeded: builtins.int = ...,
        calls_failed: builtins.int = ...,
        last_call_started_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_call_started_timestamp",b"last_call_started_timestamp","trace",b"trace"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["calls_failed",b"calls_failed","calls_started",b"calls_started","calls_succeeded",b"calls_succeeded","last_call_started_timestamp",b"last_call_started_timestamp","trace",b"trace"]) -> None: ...
global___ServerData = ServerData

class Socket(google.protobuf.message.Message):
    """Information about an actual connection.  Pronounced "sock-ay"."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REF_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    SECURITY_FIELD_NUMBER: builtins.int
    REMOTE_NAME_FIELD_NUMBER: builtins.int
    @property
    def ref(self) -> global___SocketRef:
        """The identifier for the Socket."""
        pass
    @property
    def data(self) -> global___SocketData:
        """Data specific to this Socket."""
        pass
    @property
    def local(self) -> global___Address:
        """The locally bound address."""
        pass
    @property
    def remote(self) -> global___Address:
        """The remote bound address.  May be absent."""
        pass
    @property
    def security(self) -> global___Security:
        """Security details for this socket.  May be absent if not available, or
        there is no security on the socket.
        """
        pass
    remote_name: typing.Text
    """Optional, represents the name of the remote endpoint, if different than
    the original target name.
    """

    def __init__(self,
        *,
        ref: typing.Optional[global___SocketRef] = ...,
        data: typing.Optional[global___SocketData] = ...,
        local: typing.Optional[global___Address] = ...,
        remote: typing.Optional[global___Address] = ...,
        security: typing.Optional[global___Security] = ...,
        remote_name: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data",b"data","local",b"local","ref",b"ref","remote",b"remote","security",b"security"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data","local",b"local","ref",b"ref","remote",b"remote","remote_name",b"remote_name","security",b"security"]) -> None: ...
global___Socket = Socket

class SocketData(google.protobuf.message.Message):
    """SocketData is data associated for a specific Socket.  The fields present
    are specific to the implementation, so there may be minor differences in
    the semantics.  (e.g. flow control windows)
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STREAMS_STARTED_FIELD_NUMBER: builtins.int
    STREAMS_SUCCEEDED_FIELD_NUMBER: builtins.int
    STREAMS_FAILED_FIELD_NUMBER: builtins.int
    MESSAGES_SENT_FIELD_NUMBER: builtins.int
    MESSAGES_RECEIVED_FIELD_NUMBER: builtins.int
    KEEP_ALIVES_SENT_FIELD_NUMBER: builtins.int
    LAST_LOCAL_STREAM_CREATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_REMOTE_STREAM_CREATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_MESSAGE_SENT_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_MESSAGE_RECEIVED_TIMESTAMP_FIELD_NUMBER: builtins.int
    LOCAL_FLOW_CONTROL_WINDOW_FIELD_NUMBER: builtins.int
    REMOTE_FLOW_CONTROL_WINDOW_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    streams_started: builtins.int
    """The number of streams that have been started."""

    streams_succeeded: builtins.int
    """The number of streams that have ended successfully:
    On client side, received frame with eos bit set;
    On server side, sent frame with eos bit set.
    """

    streams_failed: builtins.int
    """The number of streams that have ended unsuccessfully:
    On client side, ended without receiving frame with eos bit set;
    On server side, ended without sending frame with eos bit set.
    """

    messages_sent: builtins.int
    """The number of grpc messages successfully sent on this socket."""

    messages_received: builtins.int
    """The number of grpc messages received on this socket."""

    keep_alives_sent: builtins.int
    """The number of keep alives sent.  This is typically implemented with HTTP/2
    ping messages.
    """

    @property
    def last_local_stream_created_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The last time a stream was created by this endpoint.  Usually unset for
        servers.
        """
        pass
    @property
    def last_remote_stream_created_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The last time a stream was created by the remote endpoint.  Usually unset
        for clients.
        """
        pass
    @property
    def last_message_sent_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The last time a message was sent by this endpoint."""
        pass
    @property
    def last_message_received_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The last time a message was received by this endpoint."""
        pass
    @property
    def local_flow_control_window(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The amount of window, granted to the local endpoint by the remote endpoint.
        This may be slightly out of date due to network latency.  This does NOT
        include stream level or TCP level flow control info.
        """
        pass
    @property
    def remote_flow_control_window(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The amount of window, granted to the remote endpoint by the local endpoint.
        This may be slightly out of date due to network latency.  This does NOT
        include stream level or TCP level flow control info.
        """
        pass
    @property
    def option(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SocketOption]:
        """Socket options set on this socket.  May be absent if 'summary' is set
        on GetSocketRequest.
        """
        pass
    def __init__(self,
        *,
        streams_started: builtins.int = ...,
        streams_succeeded: builtins.int = ...,
        streams_failed: builtins.int = ...,
        messages_sent: builtins.int = ...,
        messages_received: builtins.int = ...,
        keep_alives_sent: builtins.int = ...,
        last_local_stream_created_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        last_remote_stream_created_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        last_message_sent_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        last_message_received_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        local_flow_control_window: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        remote_flow_control_window: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        option: typing.Optional[typing.Iterable[global___SocketOption]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_local_stream_created_timestamp",b"last_local_stream_created_timestamp","last_message_received_timestamp",b"last_message_received_timestamp","last_message_sent_timestamp",b"last_message_sent_timestamp","last_remote_stream_created_timestamp",b"last_remote_stream_created_timestamp","local_flow_control_window",b"local_flow_control_window","remote_flow_control_window",b"remote_flow_control_window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["keep_alives_sent",b"keep_alives_sent","last_local_stream_created_timestamp",b"last_local_stream_created_timestamp","last_message_received_timestamp",b"last_message_received_timestamp","last_message_sent_timestamp",b"last_message_sent_timestamp","last_remote_stream_created_timestamp",b"last_remote_stream_created_timestamp","local_flow_control_window",b"local_flow_control_window","messages_received",b"messages_received","messages_sent",b"messages_sent","option",b"option","remote_flow_control_window",b"remote_flow_control_window","streams_failed",b"streams_failed","streams_started",b"streams_started","streams_succeeded",b"streams_succeeded"]) -> None: ...
global___SocketData = SocketData

class Address(google.protobuf.message.Message):
    """Address represents the address used to create the socket."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class TcpIpAddress(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        IP_ADDRESS_FIELD_NUMBER: builtins.int
        PORT_FIELD_NUMBER: builtins.int
        ip_address: builtins.bytes
        """Either the IPv4 or IPv6 address in bytes.  Will be either 4 bytes or 16
        bytes in length.
        """

        port: builtins.int
        """0-64k, or -1 if not appropriate."""

        def __init__(self,
            *,
            ip_address: builtins.bytes = ...,
            port: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["ip_address",b"ip_address","port",b"port"]) -> None: ...

    class UdsAddress(google.protobuf.message.Message):
        """A Unix Domain Socket address."""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        FILENAME_FIELD_NUMBER: builtins.int
        filename: typing.Text
        def __init__(self,
            *,
            filename: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["filename",b"filename"]) -> None: ...

    class OtherAddress(google.protobuf.message.Message):
        """An address type not included above."""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        NAME_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: typing.Text
        """The human readable version of the value.  This value should be set."""

        @property
        def value(self) -> google.protobuf.any_pb2.Any:
            """The actual address message."""
            pass
        def __init__(self,
            *,
            name: typing.Text = ...,
            value: typing.Optional[google.protobuf.any_pb2.Any] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["name",b"name","value",b"value"]) -> None: ...

    TCPIP_ADDRESS_FIELD_NUMBER: builtins.int
    UDS_ADDRESS_FIELD_NUMBER: builtins.int
    OTHER_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def tcpip_address(self) -> global___Address.TcpIpAddress: ...
    @property
    def uds_address(self) -> global___Address.UdsAddress: ...
    @property
    def other_address(self) -> global___Address.OtherAddress: ...
    def __init__(self,
        *,
        tcpip_address: typing.Optional[global___Address.TcpIpAddress] = ...,
        uds_address: typing.Optional[global___Address.UdsAddress] = ...,
        other_address: typing.Optional[global___Address.OtherAddress] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["address",b"address","other_address",b"other_address","tcpip_address",b"tcpip_address","uds_address",b"uds_address"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","other_address",b"other_address","tcpip_address",b"tcpip_address","uds_address",b"uds_address"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["address",b"address"]) -> typing.Optional[typing_extensions.Literal["tcpip_address","uds_address","other_address"]]: ...
global___Address = Address

class Security(google.protobuf.message.Message):
    """Security represents details about how secure the socket is."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class Tls(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        STANDARD_NAME_FIELD_NUMBER: builtins.int
        OTHER_NAME_FIELD_NUMBER: builtins.int
        LOCAL_CERTIFICATE_FIELD_NUMBER: builtins.int
        REMOTE_CERTIFICATE_FIELD_NUMBER: builtins.int
        standard_name: typing.Text
        """The cipher suite name in the RFC 4346 format:
        https://tools.ietf.org/html/rfc4346#appendix-C
        """

        other_name: typing.Text
        """Some other way to describe the cipher suite if
        the RFC 4346 name is not available.
        """

        local_certificate: builtins.bytes
        """the certificate used by this endpoint."""

        remote_certificate: builtins.bytes
        """the certificate used by the remote endpoint."""

        def __init__(self,
            *,
            standard_name: typing.Text = ...,
            other_name: typing.Text = ...,
            local_certificate: builtins.bytes = ...,
            remote_certificate: builtins.bytes = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["cipher_suite",b"cipher_suite","other_name",b"other_name","standard_name",b"standard_name"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["cipher_suite",b"cipher_suite","local_certificate",b"local_certificate","other_name",b"other_name","remote_certificate",b"remote_certificate","standard_name",b"standard_name"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["cipher_suite",b"cipher_suite"]) -> typing.Optional[typing_extensions.Literal["standard_name","other_name"]]: ...

    class OtherSecurity(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        NAME_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: typing.Text
        """The human readable version of the value."""

        @property
        def value(self) -> google.protobuf.any_pb2.Any:
            """The actual security details message."""
            pass
        def __init__(self,
            *,
            name: typing.Text = ...,
            value: typing.Optional[google.protobuf.any_pb2.Any] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["name",b"name","value",b"value"]) -> None: ...

    TLS_FIELD_NUMBER: builtins.int
    OTHER_FIELD_NUMBER: builtins.int
    @property
    def tls(self) -> global___Security.Tls: ...
    @property
    def other(self) -> global___Security.OtherSecurity: ...
    def __init__(self,
        *,
        tls: typing.Optional[global___Security.Tls] = ...,
        other: typing.Optional[global___Security.OtherSecurity] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model",b"model","other",b"other","tls",b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model",b"model","other",b"other","tls",b"tls"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["model",b"model"]) -> typing.Optional[typing_extensions.Literal["tls","other"]]: ...
global___Security = Security

class SocketOption(google.protobuf.message.Message):
    """SocketOption represents socket options for a socket.  Specifically, these
    are the options returned by getsockopt().
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    ADDITIONAL_FIELD_NUMBER: builtins.int
    name: typing.Text
    """The full name of the socket option.  Typically this will be the upper case
    name, such as "SO_REUSEPORT".
    """

    value: typing.Text
    """The human readable value of this socket option.  At least one of value or
    additional will be set.
    """

    @property
    def additional(self) -> google.protobuf.any_pb2.Any:
        """Additional data associated with the socket option.  At least one of value
        or additional will be set.
        """
        pass
    def __init__(self,
        *,
        name: typing.Text = ...,
        value: typing.Text = ...,
        additional: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["additional",b"additional"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional",b"additional","name",b"name","value",b"value"]) -> None: ...
global___SocketOption = SocketOption

class SocketOptionTimeout(google.protobuf.message.Message):
    """For use with SocketOption's additional field.  This is primarily used for
    SO_RCVTIMEO and SO_SNDTIMEO
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DURATION_FIELD_NUMBER: builtins.int
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(self,
        *,
        duration: typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration",b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration",b"duration"]) -> None: ...
global___SocketOptionTimeout = SocketOptionTimeout

class SocketOptionLinger(google.protobuf.message.Message):
    """For use with SocketOption's additional field.  This is primarily used for
    SO_LINGER.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACTIVE_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    active: builtins.bool
    """active maps to `struct linger.l_onoff`"""

    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """duration maps to `struct linger.l_linger`"""
        pass
    def __init__(self,
        *,
        active: builtins.bool = ...,
        duration: typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration",b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active",b"active","duration",b"duration"]) -> None: ...
global___SocketOptionLinger = SocketOptionLinger

class SocketOptionTcpInfo(google.protobuf.message.Message):
    """For use with SocketOption's additional field.  Tcp info for
    SOL_TCP and TCP_INFO.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TCPI_STATE_FIELD_NUMBER: builtins.int
    TCPI_CA_STATE_FIELD_NUMBER: builtins.int
    TCPI_RETRANSMITS_FIELD_NUMBER: builtins.int
    TCPI_PROBES_FIELD_NUMBER: builtins.int
    TCPI_BACKOFF_FIELD_NUMBER: builtins.int
    TCPI_OPTIONS_FIELD_NUMBER: builtins.int
    TCPI_SND_WSCALE_FIELD_NUMBER: builtins.int
    TCPI_RCV_WSCALE_FIELD_NUMBER: builtins.int
    TCPI_RTO_FIELD_NUMBER: builtins.int
    TCPI_ATO_FIELD_NUMBER: builtins.int
    TCPI_SND_MSS_FIELD_NUMBER: builtins.int
    TCPI_RCV_MSS_FIELD_NUMBER: builtins.int
    TCPI_UNACKED_FIELD_NUMBER: builtins.int
    TCPI_SACKED_FIELD_NUMBER: builtins.int
    TCPI_LOST_FIELD_NUMBER: builtins.int
    TCPI_RETRANS_FIELD_NUMBER: builtins.int
    TCPI_FACKETS_FIELD_NUMBER: builtins.int
    TCPI_LAST_DATA_SENT_FIELD_NUMBER: builtins.int
    TCPI_LAST_ACK_SENT_FIELD_NUMBER: builtins.int
    TCPI_LAST_DATA_RECV_FIELD_NUMBER: builtins.int
    TCPI_LAST_ACK_RECV_FIELD_NUMBER: builtins.int
    TCPI_PMTU_FIELD_NUMBER: builtins.int
    TCPI_RCV_SSTHRESH_FIELD_NUMBER: builtins.int
    TCPI_RTT_FIELD_NUMBER: builtins.int
    TCPI_RTTVAR_FIELD_NUMBER: builtins.int
    TCPI_SND_SSTHRESH_FIELD_NUMBER: builtins.int
    TCPI_SND_CWND_FIELD_NUMBER: builtins.int
    TCPI_ADVMSS_FIELD_NUMBER: builtins.int
    TCPI_REORDERING_FIELD_NUMBER: builtins.int
    tcpi_state: builtins.int
    tcpi_ca_state: builtins.int
    tcpi_retransmits: builtins.int
    tcpi_probes: builtins.int
    tcpi_backoff: builtins.int
    tcpi_options: builtins.int
    tcpi_snd_wscale: builtins.int
    tcpi_rcv_wscale: builtins.int
    tcpi_rto: builtins.int
    tcpi_ato: builtins.int
    tcpi_snd_mss: builtins.int
    tcpi_rcv_mss: builtins.int
    tcpi_unacked: builtins.int
    tcpi_sacked: builtins.int
    tcpi_lost: builtins.int
    tcpi_retrans: builtins.int
    tcpi_fackets: builtins.int
    tcpi_last_data_sent: builtins.int
    tcpi_last_ack_sent: builtins.int
    tcpi_last_data_recv: builtins.int
    tcpi_last_ack_recv: builtins.int
    tcpi_pmtu: builtins.int
    tcpi_rcv_ssthresh: builtins.int
    tcpi_rtt: builtins.int
    tcpi_rttvar: builtins.int
    tcpi_snd_ssthresh: builtins.int
    tcpi_snd_cwnd: builtins.int
    tcpi_advmss: builtins.int
    tcpi_reordering: builtins.int
    def __init__(self,
        *,
        tcpi_state: builtins.int = ...,
        tcpi_ca_state: builtins.int = ...,
        tcpi_retransmits: builtins.int = ...,
        tcpi_probes: builtins.int = ...,
        tcpi_backoff: builtins.int = ...,
        tcpi_options: builtins.int = ...,
        tcpi_snd_wscale: builtins.int = ...,
        tcpi_rcv_wscale: builtins.int = ...,
        tcpi_rto: builtins.int = ...,
        tcpi_ato: builtins.int = ...,
        tcpi_snd_mss: builtins.int = ...,
        tcpi_rcv_mss: builtins.int = ...,
        tcpi_unacked: builtins.int = ...,
        tcpi_sacked: builtins.int = ...,
        tcpi_lost: builtins.int = ...,
        tcpi_retrans: builtins.int = ...,
        tcpi_fackets: builtins.int = ...,
        tcpi_last_data_sent: builtins.int = ...,
        tcpi_last_ack_sent: builtins.int = ...,
        tcpi_last_data_recv: builtins.int = ...,
        tcpi_last_ack_recv: builtins.int = ...,
        tcpi_pmtu: builtins.int = ...,
        tcpi_rcv_ssthresh: builtins.int = ...,
        tcpi_rtt: builtins.int = ...,
        tcpi_rttvar: builtins.int = ...,
        tcpi_snd_ssthresh: builtins.int = ...,
        tcpi_snd_cwnd: builtins.int = ...,
        tcpi_advmss: builtins.int = ...,
        tcpi_reordering: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tcpi_advmss",b"tcpi_advmss","tcpi_ato",b"tcpi_ato","tcpi_backoff",b"tcpi_backoff","tcpi_ca_state",b"tcpi_ca_state","tcpi_fackets",b"tcpi_fackets","tcpi_last_ack_recv",b"tcpi_last_ack_recv","tcpi_last_ack_sent",b"tcpi_last_ack_sent","tcpi_last_data_recv",b"tcpi_last_data_recv","tcpi_last_data_sent",b"tcpi_last_data_sent","tcpi_lost",b"tcpi_lost","tcpi_options",b"tcpi_options","tcpi_pmtu",b"tcpi_pmtu","tcpi_probes",b"tcpi_probes","tcpi_rcv_mss",b"tcpi_rcv_mss","tcpi_rcv_ssthresh",b"tcpi_rcv_ssthresh","tcpi_rcv_wscale",b"tcpi_rcv_wscale","tcpi_reordering",b"tcpi_reordering","tcpi_retrans",b"tcpi_retrans","tcpi_retransmits",b"tcpi_retransmits","tcpi_rto",b"tcpi_rto","tcpi_rtt",b"tcpi_rtt","tcpi_rttvar",b"tcpi_rttvar","tcpi_sacked",b"tcpi_sacked","tcpi_snd_cwnd",b"tcpi_snd_cwnd","tcpi_snd_mss",b"tcpi_snd_mss","tcpi_snd_ssthresh",b"tcpi_snd_ssthresh","tcpi_snd_wscale",b"tcpi_snd_wscale","tcpi_state",b"tcpi_state","tcpi_unacked",b"tcpi_unacked"]) -> None: ...
global___SocketOptionTcpInfo = SocketOptionTcpInfo

class GetTopChannelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_CHANNEL_ID_FIELD_NUMBER: builtins.int
    MAX_RESULTS_FIELD_NUMBER: builtins.int
    start_channel_id: builtins.int
    """start_channel_id indicates that only channels at or above this id should be
    included in the results.
    To request the first page, this should be set to 0. To request
    subsequent pages, the client generates this value by adding 1 to
    the highest seen result ID.
    """

    max_results: builtins.int
    """If non-zero, the server will return a page of results containing
    at most this many items. If zero, the server will choose a
    reasonable page size.  Must never be negative.
    """

    def __init__(self,
        *,
        start_channel_id: builtins.int = ...,
        max_results: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_results",b"max_results","start_channel_id",b"start_channel_id"]) -> None: ...
global___GetTopChannelsRequest = GetTopChannelsRequest

class GetTopChannelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CHANNEL_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Channel]:
        """list of channels that the connection detail service knows about.  Sorted in
        ascending channel_id order.
        Must contain at least 1 result, otherwise 'end' must be true.
        """
        pass
    end: builtins.bool
    """If set, indicates that the list of channels is the final list.  Requesting
    more channels can only return more if they are created after this RPC
    completes.
    """

    def __init__(self,
        *,
        channel: typing.Optional[typing.Iterable[global___Channel]] = ...,
        end: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel",b"channel","end",b"end"]) -> None: ...
global___GetTopChannelsResponse = GetTopChannelsResponse

class GetServersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_SERVER_ID_FIELD_NUMBER: builtins.int
    MAX_RESULTS_FIELD_NUMBER: builtins.int
    start_server_id: builtins.int
    """start_server_id indicates that only servers at or above this id should be
    included in the results.
    To request the first page, this must be set to 0. To request
    subsequent pages, the client generates this value by adding 1 to
    the highest seen result ID.
    """

    max_results: builtins.int
    """If non-zero, the server will return a page of results containing
    at most this many items. If zero, the server will choose a
    reasonable page size.  Must never be negative.
    """

    def __init__(self,
        *,
        start_server_id: builtins.int = ...,
        max_results: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_results",b"max_results","start_server_id",b"start_server_id"]) -> None: ...
global___GetServersRequest = GetServersRequest

class GetServersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SERVER_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def server(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Server]:
        """list of servers that the connection detail service knows about.  Sorted in
        ascending server_id order.
        Must contain at least 1 result, otherwise 'end' must be true.
        """
        pass
    end: builtins.bool
    """If set, indicates that the list of servers is the final list.  Requesting
    more servers will only return more if they are created after this RPC
    completes.
    """

    def __init__(self,
        *,
        server: typing.Optional[typing.Iterable[global___Server]] = ...,
        end: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end",b"end","server",b"server"]) -> None: ...
global___GetServersResponse = GetServersResponse

class GetServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.int
    """server_id is the identifier of the specific server to get."""

    def __init__(self,
        *,
        server_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["server_id",b"server_id"]) -> None: ...
global___GetServerRequest = GetServerRequest

class GetServerResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SERVER_FIELD_NUMBER: builtins.int
    @property
    def server(self) -> global___Server:
        """The Server that corresponds to the requested server_id.  This field
        should be set.
        """
        pass
    def __init__(self,
        *,
        server: typing.Optional[global___Server] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["server",b"server"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["server",b"server"]) -> None: ...
global___GetServerResponse = GetServerResponse

class GetServerSocketsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SERVER_ID_FIELD_NUMBER: builtins.int
    START_SOCKET_ID_FIELD_NUMBER: builtins.int
    MAX_RESULTS_FIELD_NUMBER: builtins.int
    server_id: builtins.int
    start_socket_id: builtins.int
    """start_socket_id indicates that only sockets at or above this id should be
    included in the results.
    To request the first page, this must be set to 0. To request
    subsequent pages, the client generates this value by adding 1 to
    the highest seen result ID.
    """

    max_results: builtins.int
    """If non-zero, the server will return a page of results containing
    at most this many items. If zero, the server will choose a
    reasonable page size.  Must never be negative.
    """

    def __init__(self,
        *,
        server_id: builtins.int = ...,
        start_socket_id: builtins.int = ...,
        max_results: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_results",b"max_results","server_id",b"server_id","start_socket_id",b"start_socket_id"]) -> None: ...
global___GetServerSocketsRequest = GetServerSocketsRequest

class GetServerSocketsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SOCKET_REF_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def socket_ref(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SocketRef]:
        """list of socket refs that the connection detail service knows about.  Sorted in
        ascending socket_id order.
        Must contain at least 1 result, otherwise 'end' must be true.
        """
        pass
    end: builtins.bool
    """If set, indicates that the list of sockets is the final list.  Requesting
    more sockets will only return more if they are created after this RPC
    completes.
    """

    def __init__(self,
        *,
        socket_ref: typing.Optional[typing.Iterable[global___SocketRef]] = ...,
        end: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end",b"end","socket_ref",b"socket_ref"]) -> None: ...
global___GetServerSocketsResponse = GetServerSocketsResponse

class GetChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.int
    """channel_id is the identifier of the specific channel to get."""

    def __init__(self,
        *,
        channel_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_id",b"channel_id"]) -> None: ...
global___GetChannelRequest = GetChannelRequest

class GetChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CHANNEL_FIELD_NUMBER: builtins.int
    @property
    def channel(self) -> global___Channel:
        """The Channel that corresponds to the requested channel_id.  This field
        should be set.
        """
        pass
    def __init__(self,
        *,
        channel: typing.Optional[global___Channel] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["channel",b"channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel",b"channel"]) -> None: ...
global___GetChannelResponse = GetChannelResponse

class GetSubchannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SUBCHANNEL_ID_FIELD_NUMBER: builtins.int
    subchannel_id: builtins.int
    """subchannel_id is the identifier of the specific subchannel to get."""

    def __init__(self,
        *,
        subchannel_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["subchannel_id",b"subchannel_id"]) -> None: ...
global___GetSubchannelRequest = GetSubchannelRequest

class GetSubchannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SUBCHANNEL_FIELD_NUMBER: builtins.int
    @property
    def subchannel(self) -> global___Subchannel:
        """The Subchannel that corresponds to the requested subchannel_id.  This
        field should be set.
        """
        pass
    def __init__(self,
        *,
        subchannel: typing.Optional[global___Subchannel] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subchannel",b"subchannel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subchannel",b"subchannel"]) -> None: ...
global___GetSubchannelResponse = GetSubchannelResponse

class GetSocketRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SOCKET_ID_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    socket_id: builtins.int
    """socket_id is the identifier of the specific socket to get."""

    summary: builtins.bool
    """If true, the response will contain only high level information
    that is inexpensive to obtain. Fields thay may be omitted are
    documented.
    """

    def __init__(self,
        *,
        socket_id: builtins.int = ...,
        summary: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["socket_id",b"socket_id","summary",b"summary"]) -> None: ...
global___GetSocketRequest = GetSocketRequest

class GetSocketResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SOCKET_FIELD_NUMBER: builtins.int
    @property
    def socket(self) -> global___Socket:
        """The Socket that corresponds to the requested socket_id.  This field
        should be set.
        """
        pass
    def __init__(self,
        *,
        socket: typing.Optional[global___Socket] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["socket",b"socket"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["socket",b"socket"]) -> None: ...
global___GetSocketResponse = GetSocketResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ServerReflectionRequest(google.protobuf.message.Message):
    """The message sent by the client when calling ServerReflectionInfo method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HOST_FIELD_NUMBER: builtins.int
    FILE_BY_FILENAME_FIELD_NUMBER: builtins.int
    FILE_CONTAINING_SYMBOL_FIELD_NUMBER: builtins.int
    FILE_CONTAINING_EXTENSION_FIELD_NUMBER: builtins.int
    ALL_EXTENSION_NUMBERS_OF_TYPE_FIELD_NUMBER: builtins.int
    LIST_SERVICES_FIELD_NUMBER: builtins.int
    host: typing.Text
    file_by_filename: typing.Text
    """Find a proto file by the file name."""

    file_containing_symbol: typing.Text
    """Find the proto file that declares the given fully-qualified symbol name.
    This field should be a fully-qualified symbol name
    (e.g. <package>.<service>[.<method>] or <package>.<type>).
    """

    @property
    def file_containing_extension(self) -> global___ExtensionRequest:
        """Find the proto file which defines an extension extending the given
        message type with the given field number.
        """
        pass
    all_extension_numbers_of_type: typing.Text
    """Finds the tag numbers used by all known extensions of the given message
    type, and appends them to ExtensionNumberResponse in an undefined order.
    Its corresponding method is best-effort: it's not guaranteed that the
    reflection service will implement this method, and it's not guaranteed
    that this method will provide all extensions. Returns
    StatusCode::UNIMPLEMENTED if it's not implemented.
    This field should be a fully-qualified type name. The format is
    <package>.<type>
    """

    list_services: typing.Text
    """List the full names of registered services. The content will not be
    checked.
    """

    def __init__(self,
        *,
        host: typing.Text = ...,
        file_by_filename: typing.Text = ...,
        file_containing_symbol: typing.Text = ...,
        file_containing_extension: typing.Optional[global___ExtensionRequest] = ...,
        all_extension_numbers_of_type: typing.Text = ...,
        list_services: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["all_extension_numbers_of_type",b"all_extension_numbers_of_type","file_by_filename",b"file_by_filename","file_containing_extension",b"file_containing_extension","file_containing_symbol",b"file_containing_symbol","list_services",b"list_services","message_request",b"message_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_extension_numbers_of_type",b"all_extension_numbers_of_type","file_by_filename",b"file_by_filename","file_containing_extension",b"file_containing_extension","file_containing_symbol",b"file_containing_symbol","host",b"host","list_services",b"list_services","message_request",b"message_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["message_request",b"message_request"]) -> typing.Optional[typing_extensions.Literal["file_by_filename","file_containing_symbol","file_containing_extension","all_extension_numbers_of_type","list_services"]]: ...
global___ServerReflectionRequest = ServerReflectionRequest

class ExtensionRequest(google.protobuf.message.Message):
    """The type name and extension number sent by the client when requesting
    file_containing_extension.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTAINING_TYPE_FIELD_NUMBER: builtins.int
    EXTENSION_NUMBER_FIELD_NUMBER: builtins.int
    containing_type: typing.Text
    """Fully-qualified type name. The format should be <package>.<type>"""

    extension_number: builtins.int
    def __init__(self,
        *,
        containing_type: typing.Text = ...,
        extension_number: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containing_type",b"containing_type","extension_number",b"extension_number"]) -> None: ...
global___ExtensionRequest = ExtensionRequest

class ServerReflectionResponse(google.protobuf.message.Message):
    """The message sent by the server to answer ServerReflectionInfo method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALID_HOST_FIELD_NUMBER: builtins.int
    ORIGINAL_REQUEST_FIELD_NUMBER: builtins.int
    FILE_DESCRIPTOR_RESPONSE_FIELD_NUMBER: builtins.int
    ALL_EXTENSION_NUMBERS_RESPONSE_FIELD_NUMBER: builtins.int
    LIST_SERVICES_RESPONSE_FIELD_NUMBER: builtins.int
    ERROR_RESPONSE_FIELD_NUMBER: builtins.int
    valid_host: typing.Text
    @property
    def original_request(self) -> global___ServerReflectionRequest: ...
    @property
    def file_descriptor_response(self) -> global___FileDescriptorResponse:
        """This message is used to answer file_by_filename, file_containing_symbol,
        file_containing_extension requests with transitive dependencies.
        As the repeated label is not allowed in oneof fields, we use a
        FileDescriptorResponse message to encapsulate the repeated fields.
        The reflection service is allowed to avoid sending FileDescriptorProtos
        that were previously sent in response to earlier requests in the stream.
        """
        pass
    @property
    def all_extension_numbers_response(self) -> global___ExtensionNumberResponse:
        """This message is used to answer all_extension_numbers_of_type requests."""
        pass
    @property
    def list_services_response(self) -> global___ListServiceResponse:
        """This message is used to answer list_services requests."""
        pass
    @property
    def error_response(self) -> global___ErrorResponse:
        """This message is used when an error occurs."""
        pass
    def __init__(self,
        *,
        valid_host: typing.Text = ...,
        original_request: typing.Optional[global___ServerReflectionRequest] = ...,
        file_descriptor_response: typing.Optional[global___FileDescriptorResponse] = ...,
        all_extension_numbers_response: typing.Optional[global___ExtensionNumberResponse] = ...,
        list_services_response: typing.Optional[global___ListServiceResponse] = ...,
        error_response: typing.Optional[global___ErrorResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["all_extension_numbers_response",b"all_extension_numbers_response","error_response",b"error_response","file_descriptor_response",b"file_descriptor_response","list_services_response",b"list_services_response","message_response",b"message_response","original_request",b"original_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_extension_numbers_response",b"all_extension_numbers_response","error_response",b"error_response","file_descriptor_response",b"file_descriptor_response","list_services_response",b"list_services_response","message_response",b"message_response","original_request",b"original_request","valid_host",b"valid_host"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["message_response",b"message_response"]) -> typing.Optional[typing_extensions.Literal["file_descriptor_response","all_extension_numbers_response","list_services_response","error_response"]]: ...
global___ServerReflectionResponse = ServerReflectionResponse

class FileDescriptorResponse(google.protobuf.message.Message):
    """Serialized FileDescriptorProto messages sent by the server answering
    a file_by_filename, file_containing_symbol, or file_containing_extension
    request.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FILE_DESCRIPTOR_PROTO_FIELD_NUMBER: builtins.int
    @property
    def file_descriptor_proto(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]:
        """Serialized FileDescriptorProto messages. We avoid taking a dependency on
        descriptor.proto, which uses proto2 only features, by making them opaque
        bytes instead.
        """
        pass
    def __init__(self,
        *,
        file_descriptor_proto: typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_descriptor_proto",b"file_descriptor_proto"]) -> None: ...
global___FileDescriptorResponse = FileDescriptorResponse

class ExtensionNumberResponse(google.protobuf.message.Message):
    """A list of extension numbers sent by the server answering
    all_extension_numbers_of_type request.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_TYPE_NAME_FIELD_NUMBER: builtins.int
    EXTENSION_NUMBER_FIELD_NUMBER: builtins.int
    base_type_name: typing.Text
    """Full name of the base type, including the package name. The format
    is <package>.<type>
    """

    @property
    def extension_number(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        base_type_name: typing.Text = ...,
        extension_number: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_type_name",b"base_type_name","extension_number",b"extension_number"]) -> None: ...
global___ExtensionNumberResponse = ExtensionNumberResponse

class ListServiceResponse(google.protobuf.message.Message):
    """A list of ServiceResponse sent by the server answering list_services request."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SERVICE_FIELD_NUMBER: builtins.int
    @property
    def service(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceResponse]:
        """The information of each service may be expanded in the future, so we use
        ServiceResponse message to encapsulate it.
        """
        pass
    def __init__(self,
        *,
        service: typing.Optional[typing.Iterable[global___ServiceResponse]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service",b"service"]) -> None: ...
global___ListServiceResponse = ListServiceResponse

class ServiceResponse(google.protobuf.message.Message):
    """The information of a single service used by ListServiceResponse to answer
    list_services request.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    name: typing.Text
    """Full name of a registered service, including its package name. The format
    is <package>.<service>
    """

    def __init__(self,
        *,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name"]) -> None: ...
global___ServiceResponse = ServiceResponse

class ErrorResponse(google.protobuf.message.Message):
    """The error code and error message sent by the server when an error occurs."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ERROR_CODE_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    error_code: builtins.int
    """This field uses the error codes defined in grpc::StatusCode."""

    error_message: typing.Text
    def __init__(self,
        *,
        error_code: builtins.int = ...,
        error_message: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_code",b"error_code","error_message",b"error_message"]) -> None: ...
global___ErrorResponse = ErrorResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpclib/channelz/v1/channelz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"grpclib/channelz/v1/channelz.proto\x12\x10grpc.channelz.v1\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xfe\x01\n\x07\x43hannel\x12)\n\x03ref\x18\x01 \x01(\x0b\x32\x1c.grpc.channelz.v1.ChannelRef\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.grpc.channelz.v1.ChannelData\x12\x31\n\x0b\x63hannel_ref\x18\x03 \x03(\x0b\x32\x1c.grpc.channelz.v1.ChannelRef\x12\x37\n\x0esubchannel_ref\x18\x04 \x03(\x0b\x32\x1f.grpc.channelz.v1.SubchannelRef\x12/\n\nsocket_ref\x18\x05 \x03(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\"\x84\x02\n\nSubchannel\x12,\n\x03ref\x18\x01 \x01(\x0b\x32\x1f.grpc.channelz.v1.SubchannelRef\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.grpc.channelz.v1.ChannelData\x12\x31\n\x0b\x63hannel_ref\x18\x03 \x03(\x0b\x32\x1c.grpc.channelz.v1.ChannelRef\x12\x37\n\x0esubchannel_ref\x18\x04 \x03(\x0b\x32\x1f.grpc.channelz.v1.SubchannelRef\x12/\n\nsocket_ref\x18\x05 \x03(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\"\xbb\x01\n\x18\x43hannelConnectivityState\x12?\n\x05state\x18\x01 \x01(\x0e\x32\x30.grpc.channelz.v1.ChannelConnectivityState.State\"^\n\x05State\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04IDLE\x10\x01\x12\x0e\n\nCONNECTING\x10\x02\x12\t\n\x05READY\x10\x03\x12\x15\n\x11TRANSIENT_FAILURE\x10\x04\x12\x0c\n\x08SHUTDOWN\x10\x05\"\x8e\x02\n\x0b\x43hannelData\x12\x39\n\x05state\x18\x01 \x01(\x0b\x32*.grpc.channelz.v1.ChannelConnectivityState\x12\x0e\n\x06target\x18\x02 \x01(\t\x12-\n\x05trace\x18\x03 \x01(\x0b\x32\x1e.grpc.channelz.v1.ChannelTrace\x12\x15\n\rcalls_started\x18\x04 \x01(\x03\x12\x17\n\x0f\x63\x61lls_succeeded\x18\x05 \x01(\x03\x12\x14\n\x0c\x63\x61lls_failed\x18\x06 \x01(\x03\x12?\n\x1blast_call_started_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xdb\x02\n\x11\x43hannelTraceEvent\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12>\n\x08severity\x18\x02 \x01(\x0e\x32,.grpc.channelz.v1.ChannelTraceEvent.Severity\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0b\x63hannel_ref\x18\x04 \x01(\x0b\x32\x1c.grpc.channelz.v1.ChannelRefH\x00\x12\x39\n\x0esubchannel_ref\x18\x05 \x01(\x0b\x32\x1f.grpc.channelz.v1.SubchannelRefH\x00\"E\n\x08Severity\x12\x0e\n\nCT_UNKNOWN\x10\x00\x12\x0b\n\x07\x43T_INFO\x10\x01\x12\x0e\n\nCT_WARNING\x10\x02\x12\x0c\n\x08\x43T_ERROR\x10\x03\x42\x0b\n\tchild_ref\"\x96\x01\n\x0c\x43hannelTrace\x12\x19\n\x11num_events_logged\x18\x01 \x01(\x03\x12\x36\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x06\x65vents\x18\x03 \x03(\x0b\x32#.grpc.channelz.v1.ChannelTraceEvent\"R\n\nChannelRef\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t\"X\n\rSubchannelRef\x12\x15\n\rsubchannel_id\x18\x07 \x01(\x03\x12\x0c\n\x04name\x18\x08 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"P\n\tSocketRef\x12\x11\n\tsocket_id\x18\x03 \x01(\x03\x12\x0c\n\x04name\x18\x04 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t\"P\n\tServerRef\x12\x11\n\tserver_id\x18\x05 \x01(\x03\x12\x0c\n\x04name\x18\x06 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t\"\x92\x01\n\x06Server\x12(\n\x03ref\x18\x01 \x01(\x0b\x32\x1b.grpc.channelz.v1.ServerRef\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.grpc.channelz.v1.ServerData\x12\x32\n\rlisten_socket\x18\x03 \x03(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\"\xc2\x01\n\nServerData\x12-\n\x05trace\x18\x01 \x01(\x0b\x32\x1e.grpc.channelz.v1.ChannelTrace\x12\x15\n\rcalls_started\x18\x02 \x01(\x03\x12\x17\n\x0f\x63\x61lls_succeeded\x18\x03 \x01(\x03\x12\x14\n\x0c\x63\x61lls_failed\x18\x04 \x01(\x03\x12?\n\x1blast_call_started_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xf6\x01\n\x06Socket\x12(\n\x03ref\x18\x01 \x01(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.grpc.channelz.v1.SocketData\x12(\n\x05local\x18\x03 \x01(\x0b\x32\x19.grpc.channelz.v1.Address\x12)\n\x06remote\x18\x04 \x01(\x0b\x32\x19.grpc.channelz.v1.Address\x12,\n\x08security\x18\x05 \x01(\x0b\x32\x1a.grpc.channelz.v1.Security\x12\x13\n\x0bremote_name\x18\x06 \x01(\t\"\xee\x04\n\nSocketData\x12\x17\n\x0fstreams_started\x18\x01 \x01(\x03\x12\x19\n\x11streams_succeeded\x18\x02 \x01(\x03\x12\x16\n\x0estreams_failed\x18\x03 \x01(\x03\x12\x15\n\rmessages_sent\x18\x04 \x01(\x03\x12\x19\n\x11messages_received\x18\x05 \x01(\x03\x12\x18\n\x10keep_alives_sent\x18\x06 \x01(\x03\x12G\n#last_local_stream_created_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12H\n$last_remote_stream_created_timestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1blast_message_sent_timestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x1flast_message_received_timestamp\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x19local_flow_control_window\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1aremote_flow_control_window\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12.\n\x06option\x18\r \x03(\x0b\x32\x1e.grpc.channelz.v1.SocketOption\"\xe8\x02\n\x07\x41\x64\x64ress\x12?\n\rtcpip_address\x18\x01 \x01(\x0b\x32&.grpc.channelz.v1.Address.TcpIpAddressH\x00\x12;\n\x0buds_address\x18\x02 \x01(\x0b\x32$.grpc.channelz.v1.Address.UdsAddressH\x00\x12?\n\rother_address\x18\x03 \x01(\x0b\x32&.grpc.channelz.v1.Address.OtherAddressH\x00\x1a\x30\n\x0cTcpIpAddress\x12\x12\n\nip_address\x18\x01 \x01(\x0c\x12\x0c\n\x04port\x18\x02 \x01(\x05\x1a\x1e\n\nUdsAddress\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x1a\x41\n\x0cOtherAddress\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\t\n\x07\x61\x64\x64ress\"\xbe\x02\n\x08Security\x12-\n\x03tls\x18\x01 \x01(\x0b\x32\x1e.grpc.channelz.v1.Security.TlsH\x00\x12\x39\n\x05other\x18\x02 \x01(\x0b\x32(.grpc.channelz.v1.Security.OtherSecurityH\x00\x1a{\n\x03Tls\x12\x17\n\rstandard_name\x18\x01 \x01(\tH\x00\x12\x14\n\nother_name\x18\x02 \x01(\tH\x00\x12\x19\n\x11local_certificate\x18\x03 \x01(\x0c\x12\x1a\n\x12remote_certificate\x18\x04 \x01(\x0c\x42\x0e\n\x0c\x63ipher_suite\x1a\x42\n\rOtherSecurity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x07\n\x05model\"U\n\x0cSocketOption\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12(\n\nadditional\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"B\n\x13SocketOptionTimeout\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"Q\n\x12SocketOptionLinger\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12+\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xae\x05\n\x13SocketOptionTcpInfo\x12\x12\n\ntcpi_state\x18\x01 \x01(\r\x12\x15\n\rtcpi_ca_state\x18\x02 \x01(\r\x12\x18\n\x10tcpi_retransmits\x18\x03 \x01(\r\x12\x13\n\x0btcpi_probes\x18\x04 \x01(\r\x12\x14\n\x0ctcpi_backoff\x18\x05 \x01(\r\x12\x14\n\x0ctcpi_options\x18\x06 \x01(\r\x12\x17\n\x0ftcpi_snd_wscale\x18\x07 \x01(\r\x12\x17\n\x0ftcpi_rcv_wscale\x18\x08 \x01(\r\x12\x10\n\x08tcpi_rto\x18\t \x01(\r\x12\x10\n\x08tcpi_ato\x18\n \x01(\r\x12\x14\n\x0ctcpi_snd_mss\x18\x0b \x01(\r\x12\x14\n\x0ctcpi_rcv_mss\x18\x0c \x01(\r\x12\x14\n\x0ctcpi_unacked\x18\r \x01(\r\x12\x13\n\x0btcpi_sacked\x18\x0e \x01(\r\x12\x11\n\ttcpi_lost\x18\x0f \x01(\r\x12\x14\n\x0ctcpi_retrans\x18\x10 \x01(\r\x12\x14\n\x0ctcpi_fackets\x18\x11 \x01(\r\x12\x1b\n\x13tcpi_last_data_sent\x18\x12 \x01(\r\x12\x1a\n\x12tcpi_last_ack_sent\x18\x13 \x01(\r\x12\x1b\n\x13tcpi_last_data_recv\x18\x14 \x01(\r\x12\x1a\n\x12tcpi_last_ack_recv\x18\x15 \x01(\r\x12\x11\n\ttcpi_pmtu\x18\x16 \x01(\r\x12\x19\n\x11tcpi_rcv_ssthresh\x18\x17 \x01(\r\x12\x10\n\x08tcpi_rtt\x18\x18 \x01(\r\x12\x13\n\x0btcpi_rttvar\x18\x19 \x01(\r\x12\x19\n\x11tcpi_snd_ssthresh\x18\x1a \x01(\r\x12\x15\n\rtcpi_snd_cwnd\x18\x1b \x01(\r\x12\x13\n\x0btcpi_advmss\x18\x1c \x01(\r\x12\x17\n\x0ftcpi_reordering\x18\x1d \x01(\r\"F\n\x15GetTopChannelsRequest\x12\x18\n\x10start_channel_id\x18\x01 \x01(\x03\x12\x13\n\x0bmax_results\x18\x02 \x01(\x03\"Q\n\x16GetTopChannelsResponse\x12*\n\x07\x63hannel\x18\x01 \x03(\x0b\x32\x19.grpc.channelz.v1.Channel\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x08\"A\n\x11GetServersRequest\x12\x17\n\x0fstart_server_id\x18\x01 \x01(\x03\x12\x13\n\x0bmax_results\x18\x02 \x01(\x03\"K\n\x12GetServersResponse\x12(\n\x06server\x18\x01 \x03(\x0b\x32\x18.grpc.channelz.v1.Server\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x08\"%\n\x10GetServerRequest\x12\x11\n\tserver_id\x18\x01 \x01(\x03\"=\n\x11GetServerResponse\x12(\n\x06server\x18\x01 \x01(\x0b\x32\x18.grpc.channelz.v1.Server\"Z\n\x17GetServerSocketsRequest\x12\x11\n\tserver_id\x18\x01 \x01(\x03\x12\x17\n\x0fstart_socket_id\x18\x02 \x01(\x03\x12\x13\n\x0bmax_results\x18\x03 \x01(\x03\"X\n\x18GetServerSocketsResponse\x12/\n\nsocket_ref\x18\x01 \x03(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x08\"\'\n\x11GetChannelRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\"@\n\x12GetChannelResponse\x12*\n\x07\x63hannel\x18\x01 \x01(\x0b\x32\x19.grpc.channelz.v1.Channel\"-\n\x14GetSubchannelRequest\x12\x15\n\rsubchannel_id\x18\x01 \x01(\x03\"I\n\x15GetSubchannelResponse\x12\x30\n\nsubchannel\x18\x01 \x01(\x0b\x32\x1c.grpc.channelz.v1.Subchannel\"6\n\x10GetSocketRequest\x12\x11\n\tsocket_id\x18\x01 \x01(\x03\x12\x0f\n\x07summary\x18\x02 \x01(\x08\"=\n\x11GetSocketResponse\x12(\n\x06socket\x18\x01 \x01(\x0b\x32\x18.grpc.channelz.v1.Socket2\x9a\x05\n\x08\x43hannelz\x12\x63\n\x0eGetTopChannels\x12\'.grpc.channelz.v1.GetTopChannelsRequest\x1a(.grpc.channelz.v1.GetTopChannelsResponse\x12W\n\nGetServers\x12#.grpc.channelz.v1.GetServersRequest\x1a$.grpc.channelz.v1.GetServersResponse\x12T\n\tGetServer\x12\".grpc.channelz.v1.GetServerRequest\x1a#.grpc.channelz.v1.GetServerResponse\x12i\n\x10GetServerSockets\x12).grpc.channelz.v1.GetServerSocketsRequest\x1a*.grpc.channelz.v1.GetServerSocketsResponse\x12W\n\nGetChannel\x12#.grpc.channelz.v1.GetChannelRequest\x1a$.grpc.channelz.v1.GetChannelResponse\x12`\n\rGetSubchannel\x12&.grpc.channelz.v1.GetSubchannelRequest\x1a\'.grpc.channelz.v1.GetSubchannelResponse\x12T\n\tGetSocket\x12\".grpc.channelz.v1.GetSocketRequest\x1a#.grpc.channelz.v1.GetSocketResponseBX\n\x13io.grpc.channelz.v1B\rChannelzProtoP\x01Z0google.golang.org/grpc/channelz/grpc_channelz_v1b\x06proto3')



_CHANNEL = DESCRIPTOR.message_types_by_name['Channel']
_SUBCHANNEL = DESCRIPTOR.message_types_by_name['Subchannel']
_CHANNELCONNECTIVITYSTATE = DESCRIPTOR.message_types_by_name['ChannelConnectivityState']
_CHANNELDATA = DESCRIPTOR.message_types_by_name['ChannelData']
_CHANNELTRACEEVENT = DESCRIPTOR.message_types_by_name['ChannelTraceEvent']
_CHANNELTRACE = DESCRIPTOR.message_types_by_name['ChannelTrace']
_CHANNELREF = DESCRIPTOR.message_types_by_name['ChannelRef']
_SUBCHANNELREF = DESCRIPTOR.message_types_by_name['SubchannelRef']
_SOCKETREF = DESCRIPTOR.message_types_by_name['SocketRef']
_SERVERREF = DESCRIPTOR.message_types_by_name['ServerRef']
_SERVER = DESCRIPTOR.message_types_by_name['Server']
_SERVERDATA = DESCRIPTOR.message_types_by_name['ServerData']
_SOCKET = DESCRIPTOR.message_types_by_name['Socket']
_SOCKETDATA = DESCRIPTOR.message_types_by_name['SocketData']
_ADDRESS = DESCRIPTOR.message_types_by_name['Address']
_ADDRESS_TCPIPADDRESS = _ADDRESS.nested_types_by_name['TcpIpAddress']
_ADDRESS_UDSADDRESS = _ADDRESS.nested_types_by_name['UdsAddress']
_ADDRESS_OTHERADDRESS = _ADDRESS.nested_types_by_name['OtherAddress']
_SECURITY = DESCRIPTOR.message_types_by_name['Security']
_SECURITY_TLS = _SECURITY.nested_types_by_name['Tls']
_SECURITY_OTHERSECURITY = _SECURITY.nested_types_by_name['OtherSecurity']
_SOCKETOPTION = DESCRIPTOR.message_types_by_name['SocketOption']
_SOCKETOPTIONTIMEOUT = DESCRIPTOR.message_types_by_name['SocketOptionTimeout']
_SOCKETOPTIONLINGER = DESCRIPTOR.message_types_by_name['SocketOptionLinger']
_SOCKETOPTIONTCPINFO = DESCRIPTOR.message_types_by_name['SocketOptionTcpInfo']
_GETTOPCHANNELSREQUEST = DESCRIPTOR.message_types_by_name['GetTopChannelsRequest']
_GETTOPCHANNELSRESPONSE = DESCRIPTOR.message_types_by_name['GetTopChannelsResponse']
_GETSERVERSREQUEST = DESCRIPTOR.message_types_by_name['GetServersRequest']
_GETSERVERSRESPONSE = DESCRIPTOR.message_types_by_name['GetServersResponse']
_GETSERVERREQUEST = DESCRIPTOR.message_types_by_name['GetServerRequest']
_GETSERVERRESPONSE = DESCRIPTOR.message_types_by_name['GetServerResponse']
_GETSERVERSOCKETSREQUEST = DESCRIPTOR.message_types_by_name['GetServerSocketsRequest']
_GETSERVERSOCKETSRESPONSE = DESCRIPTOR.message_types_by_name['GetServerSocketsResponse']
_GETCHANNELREQUEST = DESCRIPTOR.message_types_by_name['GetChannelRequest']
_GETCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['GetChannelResponse']
_GETSUBCHANNELREQUEST = DESCRIPTOR.message_types_by_name['GetSubchannelRequest']
_GETSUBCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['GetSubchannelResponse']
_GETSOCKETREQUEST = DESCRIPTOR.message_types_by_name['GetSocketRequest']
_GETSOCKETRESPONSE = DESCRIPTOR.message_types_by_name['GetSocketResponse']
_CHANNELCONNECTIVITYSTATE_STATE = _CHANNELCONNECTIVITYSTATE.enum_types_by_name['State']
_CHANNELTRACEEVENT_SEVERITY = _CHANNELTRACEEVENT.enum_types_by_name['Severity']
Channel = _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), {
  'DESCRIPTOR' : _CHANNEL,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Channel)
  })
_sym_db.RegisterMessage(Channel)

Subchannel = _reflection.GeneratedProtocolMessageType('Subchannel', (_message.Message,), {
  'DESCRIPTOR' : _SUBCHANNEL,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Subchannel)
  })
_sym_db.RegisterMessage(Subchannel)

ChannelConnectivityState = _reflection.GeneratedProtocolMessageType('ChannelConnectivityState', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELCONNECTIVITYSTATE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelConnectivityState)
  })
_sym_db.RegisterMessage(ChannelConnectivityState)

ChannelData = _reflection.GeneratedProtocolMessageType('ChannelData', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELDATA,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelData)
  })
_sym_db.RegisterMessage(ChannelData)

ChannelTraceEvent = _reflection.GeneratedProtocolMessageType('ChannelTraceEvent', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELTRACEEVENT,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelTraceEvent)
  })
_sym_db.RegisterMessage(ChannelTraceEvent)

ChannelTrace = _reflection.GeneratedProtocolMessageType('ChannelTrace', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELTRACE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelTrace)
  })
_sym_db.RegisterMessage(ChannelTrace)

ChannelRef = _reflection.GeneratedProtocolMessageType('ChannelRef', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELREF,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelRef)
  })
_sym_db.RegisterMessage(ChannelRef)

SubchannelRef = _reflection.GeneratedProtocolMessageType('SubchannelRef', (_message.Message,), {
  'DESCRIPTOR' : _SUBCHANNELREF,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SubchannelRef)
  })
_sym_db.RegisterMessage(SubchannelRef)

SocketRef = _reflection.GeneratedProtocolMessageType('SocketRef', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETREF,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketRef)
  })
_sym_db.RegisterMessage(SocketRef)

ServerRef = _reflection.GeneratedProtocolMessageType('ServerRef', (_message.Message,), {
  'DESCRIPTOR' : _SERVERREF,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ServerRef)
  })
_sym_db.RegisterMessage(ServerRef)

Server = _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), {
  'DESCRIPTOR' : _SERVER,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Server)
  })
_sym_db.RegisterMessage(Server)

ServerData = _reflection.GeneratedProtocolMessageType('ServerData', (_message.Message,), {
  'DESCRIPTOR' : _SERVERDATA,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ServerData)
  })
_sym_db.RegisterMessage(ServerData)

Socket = _reflection.GeneratedProtocolMessageType('Socket', (_message.Message,), {
  'DESCRIPTOR' : _SOCKET,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Socket)
  })
_sym_db.RegisterMessage(Socket)

SocketData = _reflection.GeneratedProtocolMessageType('SocketData', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETDATA,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketData)
  })
_sym_db.RegisterMessage(SocketData)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {

  'TcpIpAddress' : _reflection.GeneratedProtocolMessageType('TcpIpAddress', (_message.Message,), {
    'DESCRIPTOR' : _ADDRESS_TCPIPADDRESS,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Address.TcpIpAddress)
    })
  ,

  'UdsAddress' : _reflection.GeneratedProtocolMessageType('UdsAddress', (_message.Message,), {
    'DESCRIPTOR' : _ADDRESS_UDSADDRESS,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Address.UdsAddress)
    })
  ,

  'OtherAddress' : _reflection.GeneratedProtocolMessageType('OtherAddress', (_message.Message,), {
    'DESCRIPTOR' : _ADDRESS_OTHERADDRESS,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Address.OtherAddress)
    })
  ,
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Address)
  })
_sym_db.RegisterMessage(Address)
_sym_db.RegisterMessage(Address.TcpIpAddress)
_sym_db.RegisterMessage(Address.UdsAddress)
_sym_db.RegisterMessage(Address.OtherAddress)

Security = _reflection.GeneratedProtocolMessageType('Security', (_message.Message,), {

  'Tls' : _reflection.GeneratedProtocolMessageType('Tls', (_message.Message,), {
    'DESCRIPTOR' : _SECURITY_TLS,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Security.Tls)
    })
  ,

  'OtherSecurity' : _reflection.GeneratedProtocolMessageType('OtherSecurity', (_message.Message,), {
    'DESCRIPTOR' : _SECURITY_OTHERSECURITY,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Security.OtherSecurity)
    })
  ,
  'DESCRIPTOR' : _SECURITY,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Security)
  })
_sym_db.RegisterMessage(Security)
_sym_db.RegisterMessage(Security.Tls)
_sym_db.RegisterMessage(Security.OtherSecurity)

SocketOption = _reflection.GeneratedProtocolMessageType('SocketOption', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTION,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketOption)
  })
_sym_db.RegisterMessage(SocketOption)

SocketOptionTimeout = _reflection.GeneratedProtocolMessageType('SocketOptionTimeout', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTIONTIMEOUT,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketOptionTimeout)
  })
_sym_db.RegisterMessage(SocketOptionTimeout)

SocketOptionLinger = _reflection.GeneratedProtocolMessageType('SocketOptionLinger', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTIONLINGER,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketOptionLinger)
  })
_sym_db.RegisterMessage(SocketOptionLinger)

SocketOptionTcpInfo = _reflection.GeneratedProtocolMessageType('SocketOptionTcpInfo', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTIONTCPINFO,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketOptionTcpInfo)
  })
_sym_db.RegisterMessage(SocketOptionTcpInfo)

GetTopChannelsRequest = _reflection.GeneratedProtocolMessageType('GetTopChannelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTOPCHANNELSREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetTopChannelsRequest)
  })
_sym_db.RegisterMessage(GetTopChannelsRequest)

GetTopChannelsResponse = _reflection.GeneratedProtocolMessageType('GetTopChannelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTOPCHANNELSRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetTopChannelsResponse)
  })
_sym_db.RegisterMessage(GetTopChannelsResponse)

GetServersRequest = _reflection.GeneratedProtocolMessageType('GetServersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERSREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServersRequest)
  })
_sym_db.RegisterMessage(GetServersRequest)

GetServersResponse = _reflection.GeneratedProtocolMessageType('GetServersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERSRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServersResponse)
  })
_sym_db.RegisterMessage(GetServersResponse)

GetServerRequest = _reflection.GeneratedProtocolMessageType('GetServerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServerRequest)
  })
_sym_db.RegisterMessage(GetServerRequest)

GetServerResponse = _reflection.GeneratedProtocolMessageType('GetServerResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServerResponse)
  })
_sym_db.RegisterMessage(GetServerResponse)

GetServerSocketsRequest = _reflection.GeneratedProtocolMessageType('GetServerSocketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERSOCKETSREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServerSocketsRequest)
  })
_sym_db.RegisterMessage(GetServerSocketsRequest)

GetServerSocketsResponse = _reflection.GeneratedProtocolMessageType('GetServerSocketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERSOCKETSRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServerSocketsResponse)
  })
_sym_db.RegisterMessage(GetServerSocketsResponse)

GetChannelRequest = _reflection.GeneratedProtocolMessageType('GetChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCHANNELREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetChannelRequest)
  })
_sym_db.RegisterMessage(GetChannelRequest)

GetChannelResponse = _reflection.GeneratedProtocolMessageType('GetChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCHANNELRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetChannelResponse)
  })
_sym_db.RegisterMessage(GetChannelResponse)

GetSubchannelRequest = _reflection.GeneratedProtocolMessageType('GetSubchannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSUBCHANNELREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetSubchannelRequest)
  })
_sym_db.RegisterMessage(GetSubchannelRequest)

GetSubchannelResponse = _reflection.GeneratedProtocolMessageType('GetSubchannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSUBCHANNELRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetSubchannelResponse)
  })
_sym_db.RegisterMessage(GetSubchannelResponse)

GetSocketRequest = _reflection.GeneratedProtocolMessageType('GetSocketRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSOCKETREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetSocketRequest)
  })
_sym_db.RegisterMessage(GetSocketRequest)

GetSocketResponse = _reflection.GeneratedProtocolMessageType('GetSocketResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSOCKETRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetSocketResponse)
  })
_sym_db.RegisterMessage(GetSocketResponse)

_CHANNELZ = DESCRIPTOR.services_by_name['Channelz']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023io.grpc.channelz.v1B\rChannelzProtoP\001Z0google.golang.org/grpc/channelz/grpc_channelz_v1'
  _CHANNEL._serialized_start=181
  _CHANNEL._serialized_end=435
  _SUBCHANNEL._serialized_start=438
  _SUBCHANNEL._serialized_end=698
  _CHANNELCONNECTIVITYSTATE._serialized_start=701
  _CHANNELCONNECTIVITYSTATE._serialized_end=888
  _CHANNELCONNECTIVITYSTATE_STATE._serialized_start=794
  _CHANNELCONNECTIVITYSTATE_STATE._serialized_end=888
  _CHANNELDATA._serialized_start=891
  _CHANNELDATA._serialized_end=1161
  _CHANNELTRACEEVENT._serialized_start=1164
  _CHANNELTRACEEVENT._serialized_end=1511
  _CHANNELTRACEEVENT_SEVERITY._serialized_start=1429
  _CHANNELTRACEEVENT_SEVERITY._serialized_end=1498
  _CHANNELTRACE._serialized_start=1514
  _CHANNELTRACE._serialized_end=1664
  _CHANNELREF._serialized_start=1666
  _CHANNELREF._serialized_end=1748
  _SUBCHANNELREF._serialized_start=1750
  _SUBCHANNELREF._serialized_end=1838
  _SOCKETREF._serialized_start=1840
  _SOCKETREF._serialized_end=1920
  _SERVERREF._serialized_start=1922
  _SERVERREF._serialized_end=2002
  _SERVER._serialized_start=2005
  _SERVER._serialized_end=2151
  _SERVERDATA._serialized_start=2154
  _SERVERDATA._serialized_end=2348
  _SOCKET._serialized_start=2351
  _SOCKET._serialized_end=2597
  _SOCKETDATA._serialized_start=2600
  _SOCKETDATA._serialized_end=3222
  _ADDRESS._serialized_start=3225
  _ADDRESS._serialized_end=3585
  _ADDRESS_TCPIPADDRESS._serialized_start=3427
  _ADDRESS_TCPIPADDRESS._serialized_end=3475
  _ADDRESS_UDSADDRESS._serialized_start=3477
  _ADDRESS_UDSADDRESS._serialized_end=3507
  _ADDRESS_OTHERADDRESS._serialized_start=3509
  _ADDRESS_OTHERADDRESS._serialized_end=3574
  _SECURITY._serialized_start=3588
  _SECURITY._serialized_end=3906
  _SECURITY_TLS._serialized_start=3706
  _SECURITY_TLS._serialized_end=3829
  _SECURITY_OTHERSECURITY._serialized_start=3831
  _SECURITY_OTHERSECURITY._serialized_end=3897
  _SOCKETOPTION._serialized_start=3908
  _SOCKETOPTION._serialized_end=3993
  _SOCKETOPTIONTIMEOUT._serialized_start=3995
  _SOCKETOPTIONTIMEOUT._serialized_end=4061
  _SOCKETOPTIONLINGER._serialized_start=4063
  _SOCKETOPTIONLINGER._serialized_end=4144
  _SOCKETOPTIONTCPINFO._serialized_start=4147
  _SOCKETOPTIONTCPINFO._serialized_end=4833
  _GETTOPCHANNELSREQUEST._serialized_start=4835
  _GETTOPCHANNELSREQUEST._serialized_end=4905
  _GETTOPCHANNELSRESPONSE._serialized_start=4907
  _GETTOPCHANNELSRESPONSE._serialized_end=4988
  _GETSERVERSREQUEST._serialized_start=4990
  _GETSERVERSREQUEST._serialized_end=5055
  _GETSERVERSRESPONSE._serialized_start=5057
  _GETSERVERSRESPONSE._serialized_end=5132
  _GETSERVERREQUEST._serialized_start=5134
  _GETSERVERREQUEST._serialized_end=5171
  _GETSERVERRESPONSE._serialized_start=5173
  _GETSERVERRESPONSE._serialized_end=5234
  _GETSERVERSOCKETSREQUEST._serialized_start=5236
  _GETSERVERSOCKETSREQUEST._serialized_end=5326
  _GETSERVERSOCKETSRESPONSE._serialized_start=5328
  _GETSERVERSOCKETSRESPONSE._serialized_end=5416
  _GETCHANNELREQUEST._serialized_start=5418
  _GETCHANNELREQUEST._serialized_end=5457
  _GETCHANNELRESPONSE._serialized_start=5459
  _GETCHANNELRESPONSE._serialized_end=5523
  _GETSUBCHANNELREQUEST._serialized_start=5525
  _GETSUBCHANNELREQUEST._serialized_end=5570
  _GETSUBCHANNELRESPONSE._serialized_start=5572
  _GETSUBCHANNELRESPONSE._serialized_end=5645
  _GETSOCKETREQUEST._serialized_start=5647
  _GETSOCKETREQUEST._serialized_end=5701
  _GETSOCKETRESPONSE._serialized_start=5703
  _GETSOCKETRESPONSE._serialized_end=5764
  _CHANNELZ._serialized_start=5767
  _CHANNELZ._serialized_end=6433
# @@protoc_insertion_point(module_scope)
